@@ -7,5 +7,5 @@ predefined_algs = Pre()
 
 
 def Whiten(source, dim=None):
-    return ((source - source.Mean()) / source.Std())
+    return ((source - source.Mean(dim=dim)) / source.Std(dim=dim))
 predefined_algs.register(Whiten,category="scaling")
