@@ -133,6 +133,23 @@ def yeastract(translator=None, url="http://www.yeastract.com/download/Regulation
     return (res%"yeastract").Copy()
 predefined_sources.register(yeastract,category="yeast")
 
+
+def yeast_collins_physical():
+    url = 'http://interactome-cmp.ucsf.edu/scores/combined_scores.txt';
+    sln = ('sysname1', 'genename1', 'sysname2', 'genename2', 'pe', 'conf', 'direct', 'indirect');
+    res = Read(Fetch(url)) / sln;
+
+    return (res%"pint").Copy();
+predefined_sources.register(yeast_collins_physical, name="interactome_physical", category="yeast");
+
+def yeast_collins_genetic():
+    url = 'http://interactome-cmp.ucsf.edu/sgi/collins_chr.txt';
+    sln = ('sysname1', 'genename1', 'allele1', 'sysname2', 'genename2', 'allele2', 'score', 'corr', 'dataset');
+    res = Read(Fetch(url)) / sln;
+
+    return (res%"gint").Copy();
+predefined_sources.register(yeast_collins_genetic, name="interactome_genetic", category="yeast");
+
 ################################ HUMAN ##################################
 
 def omim_genemap():
@@ -144,7 +161,7 @@ def omim_genemap():
     warning('OMIM FTP is not up to date. See ftp://ftp.ncbi.nih.gov/repository/OMIM/ARCHIVE/README.txt')
     res = Read(Fetch("ftp://ftp.ncbi.nih.gov/repository/OMIM/ARCHIVE/genemap"),dtype=rtype)
     
-    res = res.Get(HArray(_.disease1, _.disease2, _.disease3)[_ != " "]/"disease", "~")
+    res = res.Get(HArray(_.disease1, _.disease2, _.disease3).values[_ != " "]/"disease", "~")
     splitfunc = lambda x: x.split(", ")
     res = res.To(_.gene_alias,  Do=_.Each(splitfunc, dtype="[symbols:~]<string").Elem()[_ != ""])
     res = res.To(_.method,      Do=_.Each(splitfunc, dtype="[methods:~]<string").Elem()[_ != ""])
@@ -413,7 +430,7 @@ def extract_info(vals):
 
 #########################BIOGRID########################################
 
-def biogrid(orgs=[]):
+def biogrid(orgs=None):
     """
       Download the biogrid dataset.
       orgs is an array which specifies which organism(s) you want.
@@ -431,7 +448,7 @@ def biogrid(orgs=[]):
 
     for f in files:
         orgn = f.split('/')[-1].split('-')[2].replace('_', ' ');
-        if (orgs == []) or  (not orgn in orgs):
+        if orgs and  (not orgn in orgs):
           continue;
         #fi
         print "Loading file: '%s'" % (f);
