@@ -4,7 +4,7 @@ from collections import defaultdict
 import numpy
 import sys
 import cPickle
-import time
+import time, re
 
 import wrapper
 from ..constants import *
@@ -276,7 +276,7 @@ class PyExec(VisitorFactory(prefixes=("visit","unpackCast"), flags=NF_ELSE),
         toslice = self.visitUnpackArrayOp(nnode, oslice)
         toslice = self.unpackCast(nnode.type, toslice, nnode)
         
-        onode = ops.UnaryFuncAggregateOp('Set',repops_funcs.setsig, repops_funcs.Param(nslice.name, nslice.type), 1, toslice)
+        onode = ops.UnaryFuncAggregateOp('Set',repops_funcs.setsig, nslice.name, nslice.type, 1, toslice)
         return self.visitUnaryFuncAggregateOp(onode, toslice)
     
     
@@ -345,7 +345,12 @@ class PyExec(VisitorFactory(prefixes=("visit","unpackCast"), flags=NF_ELSE),
     def visitPackTupleOp(self,node, slices):
         ndata = nested_array.co_mapseq(speedtuplify,[slice.data for slice in slices],res_type=node.type)
         return slices[0].modify(data=ndata,name=node.name,rtype=node.type,dims=node.dims,bookmarks=node.bookmarks)
-   
+    
+    def visitEachOp(self,node, slices):
+        ndata = nested_array.co_mapseq(speedeach,[slice.data for slice in slices],res_type=node.type, dtype=node.type.toNumpy(), 
+                                       eachfunc=node.eachfunc, extra_params=node.extra_params, named_params=node.named_params)
+        return slices[0].modify(data=ndata,name=node.name,rtype=node.type,dims=node.dims,bookmarks=node.bookmarks)
+  
     def visitPackIndexDictOp(self, node, slices):
         names = node.type.fieldnames
         def speed_index_dictify(x):
@@ -727,12 +732,87 @@ class PyExec(VisitorFactory(prefixes=("visit","unpackCast"), flags=NF_ELSE),
                                             + str(op) + " and " + str(type1) + ", " + str(type2)
         return res
 
+
+    def stringboolLike(self, data,type_in, type_out, op, pattern, ignore_case=False):
+        p = re.compile(r"([\\]*[%_])")
+        res = re.split(p, pattern)
+        nres = []
+        for elem in res:
+            if elem.endswith('%') or elem.endswith('_'):
+                while len(elem) > 2:
+                    nres.append(re.escape("\\"))
+                    elem = elem[2:]
+                if len(elem) == 2:
+                    nres.append(re.escape(elem[-1]))
+                elif elem == '%':
+                    nres.append(r".*")
+                else:
+                    nres.append(r".")
+            else:
+                nres.append(re.escape(elem))
+        pattern = '^' + "".join(nres) + '$'
+        return self.stringboolHasPattern(data, type_in, type_out, op, pattern, ignore_case)
+        
+    def stringboolHasPattern(self, data,type_in, type_out, op, pattern, ignore_case=False):
+        p = re.compile(pattern)
+        res = []
+        if ignore_case:
+            flags = re.IGNORE_CASE
+        else:
+            flags = 0
+
+        for elem in data:
+            if elem is Missing:
+                res.append(elem)
+            else:
+                res.append(not re.search(p, elem, flags) is None)
+        return util.darray(res, type_out.toNumpy())                
+    
+    def stringarraySplitOnPattern(self, data,type_in, type_out, op, pattern, ignore_case=False, max_splits=0):
+        p = re.compile(pattern)
+        res = []
+        if ignore_case:
+            flags = re.IGNORE_CASE
+        else:
+            flags = 0
+
+        for elem in data:
+            if elem is Missing:
+                res.append(elem)
+            else:
+                res.append(re.split(p, elem, max_splits, flags))
+        return util.darray(res, type_out.toNumpy())                
+    
+    def stringtostringGeneral(self, data, type_in, type_out, op):
+        func = string_tostring[op]
+        if type_in.has_missing:
+            res = []
+            for elem in data:
+                if elem is Missing:
+                    res.append(elem)
+                else:
+                    res.append(func(elem))
+        else:
+            res = [func(elem) for elem in data]
+        return util.darray(res, type_out.toNumpy())
+
     def numberGeneral(self, data, type_in, type_out, op):
         if util.numpy16up:
             return numpy_unary_arith[op](data, dtype=type_out.toNumpy())
         else:
             return numpy_unary_arith[op](data, sig=type_out.toNumpy())
     
+    def numberLog(self, data, type_in, type_out, op):
+        if not type_in.has_missing:
+            return self.numberGeneral(data,type_in,type_out, op)
+        func = numpy_unary_arith[op]
+        return util.darray([func(elem) for elem in data], type_out.toNumpy())
+
+
+    numberLog10 = numberLog
+    numberLog2 = numberLog
+    numberSqrt = numberLog
+    
     def boolInvert(self, data, type_in, type_out, op):
         res = []
         for elem in data:
@@ -921,7 +1001,14 @@ class PyExec(VisitorFactory(prefixes=("visit","unpackCast"), flags=NF_ELSE),
         func = numpy_dimfuncs[op]
         dtype = type_out.toNumpy()
         if type_in.has_missing:                
-            return util.darray([func([elem for elem in row if not elem is Missing],axis=0) for row in data],dtype)
+            res = []
+            for row in data:
+                felems = [elem for elem in row if not elem is Missing]
+                if felems:
+                    res.append(func(felems,axis=0))
+                else:
+                    res.append(Missing)
+            return util.darray(res,dtype)
         else:            
             if(len(data.shape) < 2):
                 if(packdepth > 1):
@@ -929,7 +1016,11 @@ class PyExec(VisitorFactory(prefixes=("visit","unpackCast"), flags=NF_ELSE),
                 return util.darray([func(row,axis=0) for row in data],dtype)
             else:
                 return func(data,axis=1)
-      
+
+
+string_tostring = {'Upper':str.upper, 
+                   'Lower':str.lower}
+
 numpy_cmp = {'Equal':numpy.equal,#{{{
             'NotEqual':numpy.not_equal,
             'LessEqual':numpy.less_equal,
@@ -955,12 +1046,14 @@ numpy_dimfuncs = {
     'Any':numpy.any,
     'All':numpy.all,
     'Sum':numpy.sum,
+    'Prod':numpy.prod,
     'Median':numpy.median,
     'Argmin':numpy.argmin,
     'Argmax':numpy.argmax,
     'Std':numpy.std
     }
 
+
 python_op = {'Equal':'__eq__',
              'NotEqual':'__ne__',
              'LessEqual':'__le__',
@@ -981,7 +1074,11 @@ python_op = {'Equal':'__eq__',
 numpy_unary_arith = {
     "Invert":numpy.invert,
     "Negative":numpy.negative,
-    "Abs":numpy.abs
+    "Abs":numpy.abs,
+    "Log":numpy.log,
+    "Log2":numpy.log2,
+    "Log10":numpy.log10,
+    "Sqrt":numpy.sqrt,
     }
 
 reverse_op = {'__eq__':'__eq__',
@@ -1017,6 +1114,50 @@ def speedtuplify(seqs):
     nseq = util.darray(zip(*seqs))
     return nseq
 
+def speedeach(seqs, dtype, eachfunc, extra_params, named_params):
+    if extra_params:
+        assert not isinstance(eachfunc, context.Context), 'Cannot give extra params to Each when using context operation'
+        if named_params is False:
+            nseq = util.darray([eachfunc(*args, **extra_params) for args in zip(*seqs)],dtype)
+        else:
+            res = []
+            for args in zip(*seqs):
+                args = dict(zip(named_params, args))
+                args.update(extra_params)
+                res.append(eachfunc(**args))
+            nseq = util.darray(res,dtype)
+    else:
+        if named_params is False:
+            if(isinstance(eachfunc,context.Context)):
+                if len(seqs) == 1:
+                    nseq = util.darray([context._apply(eachfunc, arg) for arg in seqs[0]],dtype)
+                else:                    
+                    nseq = util.darray([context._apply(eachfunc, args) for args in zip(*seqs)],dtype)
+            else:
+                if len(seqs) == 1:
+                    nseq = util.darray([eachfunc(arg) for arg in seqs[0]],dtype)
+                else:                    
+                    nseq = util.darray([eachfunc(*args) for args in zip(*seqs)],dtype)
+        else:
+            res = []
+            if(isinstance(eachfunc,context.Context)):
+                if len(seqs) == 1:
+                    res = [context._apply(eachfunc,arg) for arg in seqs[0]]
+                else:
+                    for args in zip(*seqs):
+                        args = dict(zip(named_params, args))
+                        res.append(context._apply(eachfunc,args))
+            else:
+                if len(seqs) == 1:
+                    for arg in seqs[0]:
+                        args = {named_params[0]:arg}
+                        res.append(eachfunc(**args))
+                else:
+                    for args in zip(*seqs):
+                        args = dict(zip(named_params, args))
+                        res.append(eachfunc(**args))
+            nseq = util.darray(res,dtype)
+    return nseq
 
 def speedarrayify(seqs,dtype):
     nseq = numpy.array(seqs,dtype).T
